@@ -1,11 +1,9 @@
-# tests for synonyms fxn in taxize
 context("synonyms")
 
-
 test_that("synonyms returns the correct value", {
-  skip_on_cran()
-
-  tt <- synonyms("Poa annua", db = "itis")
+  vcr::use_cassette("synonyms_itis", {
+    tt <- sw(synonyms("Poa annua", db = "itis", rows = 1, verbose = FALSE))
+  })
 
 	expect_match(names(tt), "Poa annua")
 	expect_match(tt[[1]][1, "syn_name"], "Poa annua var. aquatica")
@@ -14,13 +12,13 @@ test_that("synonyms returns the correct value", {
 	expect_equal(attr(tt, "db"), "itis")
 	expect_is(tt[[1]], "data.frame")
 
-	expect_equal(dim(tt[[1]]), c(11, 5))
+	expect_gt(NROW(tt[[1]]), 1)
 })
 
 test_that("synonyms works with worms data", {
-  skip_on_cran()
-
-  tt <- synonyms('Pomatomus saltatrix', db = "worms", verbose = FALSE)
+  vcr::use_cassette("synonyms_worms", {
+    tt <- synonyms('Pomatomus saltatrix', db = "worms", verbose = FALSE)
+  })
 
   expect_match(names(tt), 'Pomatomus saltatrix')
   expect_match(tt$`Pomatomus saltatrix`$valid_name[1], 'Pomatomus saltatrix')
